@@ -131,7 +131,7 @@ class Request(object):
     @cache_property
     def basic_user(self):
         if cfg.BASIC_AUTH_SSL_ONLY and self.scheme != 'https':
-            raise Redirect('https://%s%s' % (self.host, self.full_path))
+            raise redirect('https://%s%s' % (self.host, self.full_path))
         auth = self.environ.get('HTTP_AUTHORIZATION')
         if not auth:
             raise BasicAuth
@@ -162,7 +162,7 @@ class Request(object):
         self._new_flashes.append((msg, level))
 
 
-class Response(object):
+class Response(Exception):
     code = 200  # дефолтный код ответа
     charset = 'utf-8'  # дефолтная кодировка
     encoding_errors = 'ignore'
@@ -261,14 +261,16 @@ class App(object):
                 res = Response(unicode(res), content_type='text/plain')
             for middleware in cfg.RESPONSE_MIDDLEWARES:
                 middleware(rq, res)
+        except Response, e:
+            res = e
+        except (Redirect, PermanentRedirect, BasicAuth), e:
+            res = e.res
         except NotFound, e:
             if cfg.DEBUG:
                 res = Response(make_traceback(rq.host),
                     code=404, content_type='text/plain')
             else:
                 res = cfg.ERROR_PAGES[404](rq)
-        except (Redirect, PermanentRedirect, BasicAuth), e:
-            res = e.res
         except:
             tb = make_traceback(rq.host)
             logging.error(tb)
